@@ -359,7 +359,7 @@ async def filter_mydarts_by_trend_and_anomaly(tickers: list[str], trend: Literal
             )
     # ── 핵심: 절대값 기준 내림차순 정렬 ──────────────────
     rows.sort(key=lambda item: abs(item["anomaly_score"]), reverse=True)
-    print(rows)
+    # print(rows)
     return rows
 
 
