@@ -150,7 +150,7 @@ async def filter_prophet_by_trend_and_anomaly(tickers: list[str], trend: Literal
     # prophet을 사용해서 데이터를 만들었을 경우
     keys = [f"{REDIS_PREFIX_MAP['prophet']}:{str(t).strip()}" for t in tickers]
     values = await r.mget(keys)
-    print(values)
+    # print(values)
 
     rows: list[dict] = []
     for ticker, raw in zip(tickers, values):
@@ -172,6 +172,6 @@ async def filter_prophet_by_trend_and_anomaly(tickers: list[str], trend: Literal
             )
     # ── 핵심: 절대값 기준 내림차순 정렬 ──────────────────
     rows.sort(key=lambda item: abs(item["anomaly_score"]), reverse=True)
-    print(rows)
+    # print(rows)
     return rows
 
