@@ -1,15 +1,15 @@
 from __future__ import annotations
 
+import numpy as np
+from typing import Literal
 import datetime
 import time
 import matplotlib.pyplot as plt
 import yfinance as yf
 import pandas as pd
-import json, os, redis, functools
+import hashlib
 
 from darts import TimeSeries
-from ..common.connection import get_redis_client
-
 
 from utils_hj3415 import setup_logger
 
@@ -111,63 +111,6 @@ def show_graph(data: dict[str, list]) -> None:
     plt.show()
 
 
-def redis_cached(prefix: str | None = None, default_if_miss=None):
-    """Redis 캐싱 데코레이터
-
-    Args:
-        prefix     : Redis 키 prefix (기본 = 함수.__name__)
-        default_if_miss : 캐시가 없을 때 함수 실행 대신 반환할 기본값 (기본: None)
-    """
-    ttl_h = int(os.getenv("REDIS_EXPIRE_TIME_H", 12))
-    prefix = prefix  # 나중에 wraps 안에서 참조
-    key_maker = lambda a, k: str(a[0]).lower()
-
-    def decorator(func):
-        cache_prefix = prefix or func.__name__
-
-        @functools.wraps(func)
-        def wrapper(*args, **kwargs):
-            refresh: bool = kwargs.pop("refresh", False)
-            cache_only: bool = kwargs.pop("cache_only", False)
-
-            redis_cli = get_redis_client()
-            cache_key = f"{cache_prefix}:{key_maker(args, kwargs)}"
-            ttl = ttl_h * 60 * 60
-
-            # ── 1) 캐시 조회 (refresh=False일 때만) ───────────
-            if not refresh:
-                try:
-                    raw = redis_cli.get(cache_key)
-                    if raw is not None:
-                        mylogger.info(f"cache hit {cache_key}")
-                        return json.loads(raw)
-                except redis.RedisError as e:
-                    mylogger.warning(f"Redis GET fail: {e}")
-
-            # ── 2) cache_only 처리 ────────────────────────
-            if cache_only and not refresh:
-                mylogger.info(f"cache miss {cache_key} → 기본값 반환")
-                return default_if_miss
-
-            # ── 3) 원본 함수 실행 & 캐시 갱신 ──────────
-            mylogger.info(
-                f"{cache_key} → 계산 후 캐시{' 갱신' if refresh else ' 저장'}"
-            )
-            result = func(*args, **kwargs)
-
-            try:
-                redis_cli.setex(cache_key, ttl, json.dumps(result))
-                mylogger.info(f"[redis] SETEX {cache_key} ({ttl}s)")
-            except redis.RedisError as e:
-                mylogger.warning(f"Redis SETEX fail: {e}")
-            return result
-
-        return wrapper
-    return decorator
-
-
-import numpy as np
-from typing import Literal
 
 def judge_trend(fcst: np.ndarray, slope_th: float = 0.001, pct_th  : float = 2.0) -> Literal["상승", "하락", "횡보", "미정"]:
     fcst = fcst[~np.isnan(fcst)]
@@ -183,4 +126,33 @@ def judge_trend(fcst: np.ndarray, slope_th: float = 0.001, pct_th  : float = 2.0
     return "횡보"
 
 
+def single_ticker_key_factory(args: tuple, kwargs: dict, prefix: str) -> str:
+    # ticker는 포지셔널(첫 번째)로 올 수도, 키워드로 올 수도 있으니 둘 다 처리
+    ticker = kwargs.get("ticker")
+    if ticker is None:
+        ticker = args[0] if args else ""
 
+    # 필요하면 정규화(대소문자 무시)도 가능: ticker = str(ticker).strip().lower()
+    return f"{prefix}:{str(ticker).strip()}"
+
+
+
+def trend_key_factory(args: tuple, kwargs: dict, prefix: str) -> str:
+    """
+    키 형식: <prefix>:<trend>:<shaN>
+    - tickers: lower/strip → 중복 제거 → 정렬(순서/대소문자 무시)
+    - trend  : strip
+    - 포지셔널/키워드 혼합을 시그니처에 의존하지 않고 안전히 처리
+    """
+    # 1) 인자 추출(포지셔널/키워드 모두 지원)
+    tickers = kwargs.get("tickers") if "tickers" in kwargs else (args[0] if len(args) > 0 else [])
+    trend   = kwargs.get("trend")   if "trend"   in kwargs else (args[1] if len(args) > 1 else "")
+
+    # 2) 정규화
+    norm_tickers = sorted({str(t).strip().lower() for t in (tickers or [])})
+    trend_norm   = str(trend).strip()
+
+    # 3) 해시(키 길이 때문에 축약; 대량 조합이면 16자리 권장)
+    sha = hashlib.sha1(",".join(norm_tickers).encode("utf-8")).hexdigest()[:8]   # 짧게(8)
+
+    return f"{prefix}:{trend_norm}:{sha}"
\ No newline at end of file
